==> huaweicloudsdkfrs-3.0.56-py2.py3-none-any.whl: huaweicloudsdkfrs/v2/model/search_face_by_url_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SearchFaceByUrlResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'faces': 'list[SearchFace]'
    }

    attribute_map = {
        'faces': 'faces'
    }

    def __init__(self, faces=None):
        """SearchFaceByUrlResponse - a model defined in huaweicloud sdk"""
        
        super(SearchFaceByUrlResponse, self).__init__()

        self._faces = None
        self.discriminator = None

        if faces is not None:
            self.faces = faces

    @property
    def faces(self):
        """Gets the faces of this SearchFaceByUrlResponse.

        查找的人脸集合，详见[SearchFace](zh-cn_topic_0106912071.xml)。 调用失败时无此字段。

        :return: The faces of this SearchFaceByUrlResponse.
        :rtype: list[SearchFace]
        """
        return self._faces

    @faces.setter
    def faces(self, faces):
        """Sets the faces of this SearchFaceByUrlResponse.

        查找的人脸集合，详见[SearchFace](zh-cn_topic_0106912071.xml)。 调用失败时无此字段。

        :param faces: The faces of this SearchFaceByUrlResponse.
        :type: list[SearchFace]
        """
        self._faces = faces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchFaceByUrlResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfrs-3.0.84-py2.py3-none-any.whl: huaweicloudsdkfrs/v2/model/search_face_by_url_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SearchFaceByUrlResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'faces': 'list[SearchFace]'
    }

    attribute_map = {
        'faces': 'faces'
    }

    def __init__(self, faces=None):
        """SearchFaceByUrlResponse - a model defined in huaweicloud sdk"""
        
        super(SearchFaceByUrlResponse, self).__init__()

        self._faces = None
        self.discriminator = None

        if faces is not None:
            self.faces = faces

    @property
    def faces(self):
        """Gets the faces of this SearchFaceByUrlResponse.

        查找的人脸集合，详见[SearchFace](https://support.huaweicloud.com/api-face/face_02_0019.html)。 调用失败时无此字段。

        :return: The faces of this SearchFaceByUrlResponse.
        :rtype: list[SearchFace]
        """
        return self._faces

    @faces.setter
    def faces(self, faces):
        """Sets the faces of this SearchFaceByUrlResponse.

        查找的人脸集合，详见[SearchFace](https://support.huaweicloud.com/api-face/face_02_0019.html)。 调用失败时无此字段。

        :param faces: The faces of this SearchFaceByUrlResponse.
        :type: list[SearchFace]
        """
        self._faces = faces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchFaceByUrlResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
